#
# spec file for package dt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dt
Version:        23.28
Release:        1.9
Summary:        Generic data test program
License:        MIT
Group:          System/Filesystems
URL:            https://github.com/RobinTMiller/dt
Source:         dt-%{version}.tar.xz
# PATCH-FIX-UPSTREAM dt-manpage.patch -- https://github.com/RobinTMiller/dt/issues/4
Patch0:         dt-manpage.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(uuid)

%description
dt is a generic data test program used to verify proper operation of
peripherals, file systems, device drivers, or any data stream supported
by the operating system.  In its simplest mode of operation, dt writes
and then verifys its default data pattern, then displays performance
statisics and other test parameters before exiting.  Since verification
of data is performed, dt can be thought of as a generic diagnostic tool.

%prep
%setup -q
%patch0

%build
CFLAGS=$(pkg-config --cflags uuid)
export CFLAGS="%{optflags} $CFLAGS -I.. -DAIO -DFIFO -DMMAP -D__linux__ -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64 -DTHREADS -DSCSI"
export LIBS=$(pkg-config --libs uuid)
export LDFLAGS="-Wl,--no-undefined -Wl,-z,now"
mkdir build
cd build
make %{?_smp_mflags} \
  LIBS="$LIBS" \
  CFLAGS="$CFLAGS" \
  LDFLAGS="$LDFLAGS" \
  -f ../Makefile.linux \
  VPATH=.. OS=linux

%install
install -d -m 0755 %{buildroot}%{_datadir}/%{name}
install -Dpm 0755 build/dt \
  %{buildroot}/%{_bindir}/dt
install -Dpm 0644 Documentation/dt.man  \
  %{buildroot}/%{_mandir}/man1/dt.1
install -pm 0755 Scripts/dt? \
  %{buildroot}%{_datadir}/%{name}
install -pm 0644 data/pattern_* \
  %{buildroot}%{_datadir}/%{name}

%files
%license LICENSE
%{_bindir}/dt
%{_datadir}/%{name}
%{_mandir}/man1/dt.1%{?ext_man}

%changelog
* Sat Apr 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update SPEC file, added working upstream URL
  * Use OBS services for source generation
- Update to 23.28
  * Add support for forcing FALSE data corruptiong for debugging
  * When creating log directories in setup_log_directory(),
    create the last subdirectory (as required). For user specified
    log directory, expand format control strings prior to creating
    the directory (logdir= option).
  * Create master log creation function for use by other tool parsers
  * Add support for comma separated workload[s]= option
  * When "trigger=" is specified, no parameters, then remove triggers.
  * Add array=string option, esp. for external trigger scripts.
  * Add --trigger= and --workload= parsing for I/O behavior options.
  * Add support for starting slice offset.
  * Add options for date and time field separator used when
    formatting the log prefix format strings (e.g. "%%ymd", "%%hms")
  * Apply special step option handling to both disks and files,
    by setting up and ending offset so I/O loops break reaching
    this offset.
  * Add flag for output position, so zero offset is handled properly.
  * Add "showvflags=hex" option to show block tag verify flags set
  * When selecting 100%% reads (readp=100), switch output file to
    input file.
  * Remove a file position sanity check no longer valid with
    updates made in FindCapacity() with new logic associated
    with the file position option.
  * For Unix systems, increase the open file resource limit,
    now that low limits are imposed on newer Linux distros,
    to avoid false failures!
  * Added "showfslba" and "showfsmap" commands to show the file
    system map, for the file specified, assuming we can acquire FS
    extents to map physical LBAs.
  * When re-enabling stats via "enable=stats", ensure all the stat
    flags reset when disabled, get enabled once again, esp. since
    these are sticky.
  * Add a retry data corruption limit option (retryDC_limit=value).
  * The normal retry limit is used for retrying errors (60 by default).
  * Added separate retry data corruption delay option (retryDC_delay).
  * Change the default dispose mode setting to keep on error.
  * Change the delete error log file default to be true.
  * Add logdir= option to prepend to job/log file paths.
  * Add support for capacity percentage for thin provisioned LUNs,
    to help avoid exceeding backend storage for over-provisioned
    volumes
  * Add support for appending a default file name to a directory.
  * Fix bug introduced with mounted files system check in copy mode.
  * For Linux file systems with direct I/O, get the disk block size.
  * This disk block size is required for later sanity checks for
    direct I/O.
  * Add mounted file system check when writing to /dev/ disk devices
- Dropped obsoleted  dt-default-source-define.patch and
  dt-wformat-security.patch
* Thu Jun  7 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Mon Oct  3 2016 mpluskal@suse.com
- Drop doc subpackage
* Sat Sep 10 2016 mpluskal@suse.com
- Update to version 18.32
- Sync patches from fedora:
  * dt-wformat-security.patch
  * dt-default-source-define.patch
  * dt-manpage.patch
* Tue Aug 30 2016 mpluskal@suse.com
- Correct license
- Cleanup spec file with spec-cleaner
- Disable building on 32 architectures for Factory as they fail
* Mon Feb 21 2011 hare@suse.de
- Update to version 17.25
* Tue Oct 13 2009 hare@suse.de
- Initial rpm, based on dt version 16.20
